@@ -13,13 +13,22 @@ use IO::Select;
 use IO::Pipe;
 use POSIX qw(mkfifo BUFSIZ EWOULDBLOCK);
 use Socket;
-use Thread qw(async);
 use Time::HiRes qw(gettimeofday tv_interval);
 use Tie::RefHash;
 
+BEGIN {
+    if  (! eval "require Thread") {
+        # want warnings? uncomment the next line
+        # warn "Could not import Thread.pm: $@\n";
+	$MAIN::no_thread = 1;
+    } else {
+        Thread->import();
+    }
+}
+
 @ISA = (qw(NetServer));
 
-$VERSION = "1.00";
+$VERSION = "1.01";
 
 use strict;
 
@@ -425,6 +434,11 @@ Extra test scripts
 
 Updated documentation                                                 
 
+=item 1.01
+
+Fix so it works on installations with no threading support (duh). Tested
+on Solaris, too.
+
 =back
 
 
@@ -459,6 +473,8 @@ $NetServer::FieldTypes = {
                          "handle"            => "IO::File",
                          "scoreboard"        => "hash",
                          "servername"        => "array",
+                         "parent_callback"   => "code",
+                         "ante_parent_callback"   => "code",
                       };
 
 # $NetServer::Debug; if non-zero, emit some debugging info on STDERR
@@ -812,6 +828,10 @@ sub run_thread {
     # threads. This is ugly -- may want to bodge it up to see if the 
     # run_select_fast method is a better model?
     my ($self) = shift ;
+    if ($MAIN::no_thread == 1) {
+        warn "Warning: Threading not supported!\n";
+	return;
+    }
     my %init =  (
                   LocalPort => $self->port(),
                   Listen    => $self->listen(),
@@ -926,10 +946,13 @@ sub run_fork {
     }
     # and make sure we wait() on children
     $SIG{CHLD} = 'IGNORE'; 
+    my $parent_callback = $self->parent_callback();
+    my $ante_fork_callback = $self->ante_fork_callback();                       
 
     # now loop, forking whenever a new connection arrives on the listener
     $self->root_pid($$);  # set server root PID
     while (my ($new_sock) = $main_sock->accept()) {
+        &$ante_fork_callback($self) if ( defined $ante_fork_callback );
         my $x_time = [ gettimeofday ]; # millisecond timer to track duration
         my $pid = fork();
         die "Cannot fork: $!\n" unless defined ($pid);
@@ -968,6 +991,9 @@ sub run_fork {
         } else {
             # parent
             $NetServer::Debug && print STDERR "$0:$$: forked $pid\n";
+            if ( defined $parent_callback ) {
+                 &$parent_callback($self);
+            } 
         }
     }
 }
