@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-$rc = system("$^X testguts.pl");
+$rc = system("$^X -Iblib/lib testguts.pl");
 if ($rc == 15) {
     print "ok 6\n"; # the quit() method worked -- exit via signal 15
 } else {
